verify_commitment_proof

Function verify_commitment_proof 

pub fn verify_commitment_proof(
    cmx: &[u8; 32],
    tree_root: [u8; 32],
    path_proof_raw: &[u8],
    value_hash: [u8; 32],
) -> Result<bool, NomtVerifyError>
Verify a commitment (note existence) proof against a tree root.

Returns Ok(true) if the note exists with the expected value, Ok(false) if the proof is valid but the value doesn’t match, Err if the proof is cryptographically invalid.