pub struct WalletState {
pub nullifier_set_root: [u8; 32],
pub owned_notes_root: [u8; 32],
pub note_tree_frontier: NoteFrontier,
pub block_height: u32,
pub block_hash: [u8; 32],
}Expand description
full wallet state
Fields
nullifier_set_root: [u8; 32]sparse merkle root: nullifier -> bool (has been seen)
owned_notes_root: [u8; 32]sparse merkle root: note_commitment -> NoteData
note_tree_frontier: NoteFrontierincremental merkle tree frontier for note commitment tree allows reconstructing merkle paths for spending stored as frontier hashes at each level
block_height: u32chain position
block_hash: [u8; 32]Implementations
Sourceimpl WalletState
impl WalletState
Sourcepub fn genesis_testnet() -> Self
pub fn genesis_testnet() -> Self
genesis state for testnet
Sourcepub fn commit(&self) -> WalletStateCommitment
pub fn commit(&self) -> WalletStateCommitment
commit to state (domain-separated blake2b)
Sourcepub fn is_genesis(&self) -> bool
pub fn is_genesis(&self) -> bool
check if this is genesis state