pub struct IncomingViewingKey { /* private fields */ }Expand description
A key that provides the capability to detect and decrypt incoming notes from the block chain, without being able to spend the notes or detect when they are spent.
This key is useful in situations where you only need the capability to detect inbound payments, such as merchant terminals.
This key is not suitable for use on its own in a wallet, as it cannot maintain
accurate balance. You should use a FullViewingKey instead.
Defined in Zcash Protocol Spec  5.6.4.3: Orchard Raw Incoming Viewing Keys.
Implementations
Sourceimpl IncomingViewingKey
impl IncomingViewingKey
Sourcepub fn to_bytes(&self) -> [u8; 64]
pub fn to_bytes(&self) -> [u8; 64]
Serializes an Orchard incoming viewing key to its raw encoding as specified in Zcash Protocol Spec  5.6.4.3: Orchard Raw Incoming Viewing Keys
Sourcepub fn from_bytes(bytes: &[u8; 64]) -> CtOption<IncomingViewingKey>
pub fn from_bytes(bytes: &[u8; 64]) -> CtOption<IncomingViewingKey>
Parses an Orchard incoming viewing key from its raw encoding.
Sourcepub fn diversifier_index(&self, addr: &Address) -> Option<DiversifierIndex>
pub fn diversifier_index(&self, addr: &Address) -> Option<DiversifierIndex>
Checks whether the given address was derived from this incoming viewing
key, and returns the diversifier index used to derive the address if
so. Returns None if the address was not derived from this key.
Sourcepub fn address_at(&self, j: impl Into<DiversifierIndex>) -> Address
pub fn address_at(&self, j: impl Into<DiversifierIndex>) -> Address
Returns the payment address for this key at the given index.
Sourcepub fn address(&self, d: Diversifier) -> Address
pub fn address(&self, d: Diversifier) -> Address
Returns the payment address for this key corresponding to the given diversifier.