pub struct OrchardFvk { /* private fields */ }Expand description
A key that provides the capability to view incoming and outgoing transactions.
This key is useful anywhere you need to maintain accurate balance, but do not want the ability to spend funds (such as a view-only wallet).
Defined in Zcash Protocol Spec  4.2.3: Orchard Key Components.
Implementations
Sourceimpl FullViewingKey
impl FullViewingKey
Sourcepub fn address_at(
&self,
j: impl Into<DiversifierIndex>,
scope: Scope,
) -> Address
pub fn address_at( &self, j: impl Into<DiversifierIndex>, scope: Scope, ) -> Address
Returns the payment address for this key at the given index.
Sourcepub fn address(&self, d: Diversifier, scope: Scope) -> Address
pub fn address(&self, d: Diversifier, scope: Scope) -> Address
Returns the payment address for this key corresponding to the given diversifier.
Sourcepub fn scope_for_address(&self, address: &Address) -> Option<Scope>
pub fn scope_for_address(&self, address: &Address) -> Option<Scope>
Returns the scope of the given address, or None if the address is not derived
from this full viewing key.
Sourcepub fn write<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
pub fn write<W>(&self, writer: W) -> Result<(), Error>where
W: Write,
Serializes the full viewing key as specified in Zcash Protocol Spec  5.6.4.4: Orchard Raw Full Viewing Keys
Sourcepub fn read<R>(reader: R) -> Result<FullViewingKey, Error>where
R: Read,
pub fn read<R>(reader: R) -> Result<FullViewingKey, Error>where
R: Read,
Parses a full viewing key from its “raw” encoding as specified in Zcash Protocol Spec  5.6.4.4: Orchard Raw Full Viewing Keys
Sourcepub fn to_bytes(&self) -> [u8; 96]
pub fn to_bytes(&self) -> [u8; 96]
Serializes the full viewing key as specified in Zcash Protocol Spec  5.6.4.4: Orchard Raw Full Viewing Keys
Sourcepub fn from_bytes(bytes: &[u8; 96]) -> Option<FullViewingKey>
pub fn from_bytes(bytes: &[u8; 96]) -> Option<FullViewingKey>
Parses a full viewing key from its “raw” encoding as specified in Zcash Protocol Spec  5.6.4.4: Orchard Raw Full Viewing Keys
Sourcepub fn to_ivk(&self, scope: Scope) -> IncomingViewingKey
pub fn to_ivk(&self, scope: Scope) -> IncomingViewingKey
Derives an IncomingViewingKey for this full viewing key.
Sourcepub fn to_ovk(&self, scope: Scope) -> OutgoingViewingKey
pub fn to_ovk(&self, scope: Scope) -> OutgoingViewingKey
Derives an OutgoingViewingKey for this full viewing key.