encode_trace

Function encode_trace 

pub fn encode_trace(
    headers: &[TraceHeader],
    state_roots: &[EpochStateRoots],
    initial_commitment: [u8; 32],
    initial_state_commitment: [u8; 32],
    tip_tree_root: [u8; 32],
    tip_nullifier_root: [u8; 32],
    final_actions_commitment: [u8; 32],
) -> Result<HeaderChainTrace, ZyncError>
Encode headers into a trace polynomial for ligerito proving.

Returns a HeaderChainTrace with the trace padded to the next power of 2. The sentinel row is appended after all headers with tip roots and actions commitment.