pub struct ChainVerifyResult {
pub all_proofs_valid: bool,
pub chain_continuous: bool,
pub start_outputs: ProofPublicOutputs,
pub tip_outputs: ProofPublicOutputs,
pub num_segments: usize,
}Expand description
result of chain verification across multiple proof segments
Fields
all_proofs_valid: boolall individual proofs passed the ligerito proximity test
chain_continuous: booladjacent proof public outputs satisfy continuity invariants
start_outputs: ProofPublicOutputspublic outputs of the first proof in the chain (chain start)
tip_outputs: ProofPublicOutputspublic outputs of the last proof in the chain (chain tip)
num_segments: usizenumber of segments verified